BBFrameDefrag

Struct BBFrameDefrag 

pub struct BBFrameDefrag<R> { /* private fields */ }
BBFRAME defragmenter.

This receives BBFRAME fragments from an object that implements the RecvFragment trait and performs defragmentation and validation to obtain and return full BBFRAMES.

Implementations

Source

impl<R> BBFrameDefrag<R>

pub fn new(recv_fragment: R) -> BBFrameDefrag<R>

Creates a new BBFRAME defragmenter.

The recv_fragment object is intended to be an implementor of RecvFragment that will be used to receive BBFRAME fragments.

pub fn set_isi(&mut self, isi: Option<u8>)

Set the ISI (Input Stream Indicator) to process.

When this function is called with Some(n), the BBFRAME receiver will expect an MIS (Multiple Input Stream) signal and will only process the indicated ISI. When this function is called with None, the defragmenter will expect a SIS (Single Input Stream) signal.

The default after the construction of the receiver is SIS mode.

pub fn set_header_bytes(&mut self, header_bytes: usize) -> Result<()>

Sets the number of bytes used in the header in each fragment.

The header is removed before reading the rest of the fragment, which should correpond to a BBFRAME fragment. By default, a header length of zero bytes is assumed.

The function returns an error if header_bytes is larger than HEADER_MAX_LEN.