pub struct BBFrameRecv<R> { /* private fields */ }Expand description
BBFRAME receiver.
This receives complete BBFRAMEs from an object that implements the
RecvBBFrame trait and performs validation to return valid BBFRAMES.
Implementations
Sourceimpl<R> BBFrameRecv<R>
impl<R> BBFrameRecv<R>
Sourcepub fn new(recv_bbframe: R) -> BBFrameRecv<R>
pub fn new(recv_bbframe: R) -> BBFrameRecv<R>
Creates a new BBFRAME receiver.
The recv_bbframe object is intended to be an implementor of
RecvBBFrame that will be used to receive complete BBFRAMEs.
Sourcepub fn set_isi(&mut self, isi: Option<u8>)
pub fn set_isi(&mut self, isi: Option<u8>)
Set the ISI (Input Stream Indicator) to process.
When this function is called with Some(n), the BBFRAME receiver
will expect an MIS (Multiple Input Stream) signal and will only
process the indicated ISI. When this function is called with None,
the defragmenter will expect a SIS (Single Input Stream) signal.
The default after the construction of the receiver is SIS mode.
Sourcepub fn set_header_bytes(&mut self, header_bytes: usize) -> Result<()>
pub fn set_header_bytes(&mut self, header_bytes: usize) -> Result<()>
Sets the number of bytes used in the header in each BBFRAME.
The header is removed before reading the BBFRAME. By default, a header length of zero bytes is assumed.
The function returns an error if header_bytes is larger than
HEADER_MAX_LEN.