BBFrameValidator

Struct BBFrameValidator 

pub struct BBFrameValidator { /* private fields */ }
BBFRAME validator.

This object checks if a BBFRAME is a valid BBFRAME containing GSE data in the appropriate ISI (Input Stream Indicator).

Implementations

Source

impl BBFrameValidator

pub fn new() -> BBFrameValidator

Creates a BBFRAME validator.

pub fn set_isi(&mut self, isi: Option<u8>)

Set the ISI (Input Stream Indicator) to process.

When this function is called with Some(n), the validator will expect an MIS (Multiple Input Stream) signal and only declare as valid BBFRAMEs from the the indicated ISI. When this function is called with None, the validator will expect a SIS (Single Input Stream) signal.

The default after the construction of the validator is SIS mode.

pub fn set_log_bbheader_crc_errors(&mut self, log_bbheader_crc_errors: bool)

Set the logging of BBHEADER CRC errors.

BBHEADER CRC errors are not logged by default, because BBFrameDefrag relies on checking the CRC of packets at which pontentially there is no BBHEADER in order to achieve synchronization, and this would cause spurious CRC error logs. For other BBFRAME receivers, logging of BBHEADER CRC errors can be enabled by setting log_bbheader_crc_errors to true in this call.

pub fn bbheader_is_valid(&self, bbheader: BBHeader<'_>) -> bool

Checks if a BBHEADER is valid.

The following conditions are tested:

  • CRC of the BBHEADER.

  • TS/GS type matching generic continuous or GSE-HEM.

  • SIS/MIS and ISI matching what expected according to the last BBFrameValidator::set_isi call.

  • If the BBFRAME is not GSE-HEM, then ISSYI disabled.

  • The DFL is a multiple of 8 bits and not larger than the maximum BBFRAME length.

If the BBFRAME is not valid, this function logs the reason using the log crate.