App

Struct App 

pub struct App<AppArgs = Args, Metrics = ()> { /* private fields */ }
dvb-gse CLI application.

This struct contains everything that is needed by the dvb-gse application.

The AppArgs type argument defines the type of the CLI arguments of the application. It can either be Args if no custom CLI arguments are needed, or a custom type that extends Args by implementing clap::Parser and AsRef<Args>.

The Metrics type argument defines the type of the custom metrics. The default type () is used for no metrics. It is possible to provide a type here that implements the Metrics trait to add custom metrics to the application.

Implementations

Source

impl<AppArgs: Parser, Metrics> App<AppArgs, Metrics>

pub fn new<F: FnOnce(&AppArgs) -> Result<Metrics>>( build_metrics: F, ) -> Result<Self>

Creates a dvb-gse application by parsing arguments and doing some initialization.

The App::run method needs to be called to run the application.

The build_metrics closure is used to build a Metrics object from the parsed CLI arguments.

Source

impl<AppArgs: Parser, Metrics: Default> App<AppArgs, Metrics>

pub fn with_default_metrics() -> Result<Self>

Creates a dvb-gse application with default metrics by parsing arguments and doing some initialization.

The App::run method needs to be called to run the application.

The Metrics object is constructed by calling its Default implementation.

Source

impl<AppArgs: AsRef<Args>, Metrics: MetricsTrait + Clone + Send + 'static> App<AppArgs, Metrics>

pub fn run(self) -> Result<()>

Runs the dvb-gse application.

This function only returns if there is a fatal error.