GSEPacketDefrag

Struct GSEPacketDefrag 

pub struct GSEPacketDefrag { /* private fields */ }
GSE Packet defragmenter.

This structure performs defragmentation of GSE Packets in order to obtain full PDUs.

Implementations

Source

impl GSEPacketDefrag

pub fn new() -> GSEPacketDefrag

Creates a new GSE Packet defragmenter.

pub fn set_skip_total_length_check(&mut self, value: bool)

Enables or disables the check of the total length field.

By default, GSEPacketDefrag checks that the length of the defragmented data matches the value specified in the total length check field. However, some modulators set this value incorrectly. This function can be used to skip the check of the total length field.

pub fn defragment<'a>( &'a mut self, bbframe: &'a BBFrame, ) -> Result<impl Iterator<Item = PDU> + 'a, GSEError>

Defragment a BBFRAME.

This function returns an iterator that produces all the PDUs that can be completed with the GSE Packets found in the BBFRAME.

The function returns an error if the BBFRAME is malformed. For instance, if the BBFRAME length is shorter than the BBHEADER length.