pub trait RecvBBFrame {
// Required method
fn recv_bbframe(&mut self, buf: &mut [u8; 7338]) -> Result<usize>;
}Expand description
Receiver of complete BBFRAMEs.
This trait is modeled around UdpSocket::recv_from, since the main way to
receive complete BBFRAMEs is as jumbo datagrams received from a UDP socket.
The BBFRAMEs may or may not have padding at the end. The recv_fragment
function is allowed to skip suppyling some complete BBFRAMEs, which happens
for instance if UDP packets are lost (when this trait is implemented by a
UDP socket).