pub struct Args {
pub listen: SocketAddr,
pub tun: String,
pub input: InputFormat,
pub header_length: usize,
pub isi: Option<u8>,
pub stats_interval: f64,
pub skip_total_length: bool,
pub allow_broadcast: bool,
pub allow_label: Vec<Label>,
}Expand description
Receive DVB-GSE and send PDUs into a TUN device.
Fields
listen: SocketAddrIP address and port to listen on to receive DVB-S2 BBFRAMEs.
tun: StringTUN interface name.
input: InputFormatInput format: “UDP fragments”, “UDP complete”, or “TCP”.
header_length: usizeInput header length (the header is discarded).
isi: Option<u8>ISI to process in MIS mode (if this option is not specified, run in SIS mode).
stats_interval: f64Time interval used to log statistics (in seconds).
skip_total_length: boolSkip checking the GSE total length field.
allow_broadcast: boolAllow GSE packets addressed to the broadcast label (no label).
If this argument is used, all the GSE packets not explicitly allowed via CLI arguments are dropped.
allow_label: Vec<Label>Allow GSE packets addressed to this 3-byte or 6-byte label.
If this argument is used, all the GSE packets not explicitly allowed via CLI arguments are dropped. This argument can be used multiple times to allow multiple labels.