pub struct GSEHeader { /* private fields */ }Expand description
GSE Header.
This structure stores the parsed field values from a GSE Header.
Implementations
Sourceimpl GSEHeader
impl GSEHeader
Sourcepub fn from_slice(
slice: &[u8],
re_used_label: Option<&Label>,
) -> Option<GSEHeader>
pub fn from_slice( slice: &[u8], re_used_label: Option<&Label>, ) -> Option<GSEHeader>
Creates a GSE Header by parsing the values in a slice.
On success, the GSE Header is returned.
If the slice is not long enough to fully contain the GSE Header, None
is returned. Since GSE Headers are variable-length, whether this
function returns None or not can depend on the values at the beginning
of the slice, in addition to its length.
Additionally, None is returned if the header corresponds to padding
bytes (i.e., if the contents of its fixed fields are all zero).
In order to fully parse a GSE Header, due to the concept of “label
re-use”, it is necessary to know the label of a previous GSE Header in
the same BBFRAME. This can be provided in the re_used_label
parameter. If this parameter is None and a GSE Header with START = 1
and label re-use is found in the slice, then this function fails,
returning None.
Sourcepub fn is_single_fragment(&self) -> bool
pub fn is_single_fragment(&self) -> bool
Returns true if the GSE Packet is not fragmented.
A GSE Packet is not fragmented if both its Start Indicator and its End
Indicator contain true.
Sourcepub fn label_type(&self) -> LabelType
pub fn label_type(&self) -> LabelType
Gives the value Label Type Indicator field.
Sourcepub fn gse_length(&self) -> u16
pub fn gse_length(&self) -> u16
Gives the value of the GSE Length field.
Sourcepub fn fragment_id(&self) -> Option<u8>
pub fn fragment_id(&self) -> Option<u8>
Gives the value of the Fragment ID field, if present.
Sourcepub fn total_length(&self) -> Option<u16>
pub fn total_length(&self) -> Option<u16>
Gives the value of the Total Length field, if present.
Sourcepub fn protocol_type(&self) -> Option<u16>
pub fn protocol_type(&self) -> Option<u16>
Gives the value of the Protocol Type field, if present.